==> lxqt-l10n-0.11.0-1-src.tar.xz: lxqt-l10n-0.11.0/lxqt-panel/plugin-clock/clock_ja.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ja">
<context>
    <name>FirstDayCombo</name>
    <message>
        <location filename="../../../lxqtclockconfiguration.cpp" line="49"/>
        <source>&lt;locale based&gt;</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>LXQtClockConfiguration</name>
    <message>
        <location filename="../../../lxqtclockconfiguration.ui" line="14"/>
        <source>Clock Settings</source>
        <translation>時計の設定</translation>
    </message>
    <message>
        <location filename="../../../lxqtclockconfiguration.ui" line="20"/>
        <source>Time</source>
        <translation>時刻</translation>
    </message>
    <message>
        <location filename="../../../lxqtclockconfiguration.ui" line="26"/>
        <source>&amp;Show seconds</source>
        <translation>秒を表示(&amp;S)</translation>
    </message>
    <message>
        <location filename="../../../lxqtclockconfiguration.ui" line="33"/>
        <source>12 &amp;hour style</source>
        <translation>12時間表示(&amp;H)</translation>
    </message>
    <message>
        <location filename="../../../lxqtclockconfiguration.ui" line="40"/>
        <source>&amp;Use UTC</source>
        <translation>UTCを使用する(&amp;U)</translation>
    </message>
    <message>
        <location filename="../../../lxqtclockconfiguration.ui" line="59"/>
        <source>Date &amp;format</source>
        <translation>日時の形式(&amp;F)</translation>
    </message>
    <message>
        <location filename="../../../lxqtclockconfiguration.ui" line="76"/>
        <source>&amp;Do not show date</source>
        <translation>日付を表示しない(&amp;D)</translation>
    </message>
    <message>
        <location filename="../../../lxqtclockconfiguration.ui" line="86"/>
        <source>Show date &amp;before time</source>
        <translation>日付のあとに時刻(&amp;B)</translation>
    </message>
    <message>
        <location filename="../../../lxqtclockconfiguration.ui" line="93"/>
        <source>Show date &amp;after time</source>
        <translation>時刻のあとに日付(&amp;A)</translation>
    </message>
    <message>
        <location filename="../../../lxqtclockconfiguration.ui" line="100"/>
        <source>Show date below time on new &amp;line</source>
        <translation>時刻の下に日付(&amp;L)</translation>
    </message>
    <message>
        <location filename="../../../lxqtclockconfiguration.ui" line="107"/>
        <source>First day of week in calendar</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../lxqtclockconfiguration.ui" line="124"/>
        <source>Orientation</source>
        <translation>回転</translation>
    </message>
    <message>
        <location filename="../../../lxqtclockconfiguration.ui" line="130"/>
        <source>Auto&amp;rotate when the panel is vertical</source>
        <translation>パネルが縦のときに自動回転(&amp;R)</translation>
    </message>
    <message>
        <location filename="../../../lxqtclockconfiguration.ui" line="50"/>
        <source>Date</source>
        <translation>日付</translation>
    </message>
    <message>
        <location filename="../../../lxqtclockconfiguration.cpp" line="268"/>
        <source>Input custom date format</source>
        <translation>日付の表示形式を指定</translation>
    </message>
    <message>
        <location filename="../../../lxqtclockconfiguration.cpp" line="268"/>
        <source>Interpreted sequences of date format are:

d	the day as number without a leading zero (1 to 31)
dd	the day as number with a leading zero (01 to 31)
ddd	the abbreviated localized day name (e.g. &apos;Mon&apos; to &apos;Sun&apos;).
dddd	the long localized day name (e.g. &apos;Monday&apos; to &apos;Sunday&apos;).
M	the month as number without a leading zero (1-12)
MM	the month as number with a leading zero (01-12)
MMM	the abbreviated localized month name (e.g. &apos;Jan&apos; to &apos;Dec&apos;).
MMMM	the long localized month name (e.g. &apos;January&apos; to &apos;December&apos;).
yy	the year as two digit number (00-99)
yyyy	the year as four digit number

All other input characters will be treated as text.
Any sequence of characters that are enclosed in single quotes (&apos;)
will also be treated as text and not be used as an expression.


Custom date format:</source>
        <translation>解釈される記法:

d	日(ゼロなし) (1 - 31)
dd	日(ゼロ埋め) (01 - 31)
ddd	 曜日（短い） (&apos;月&apos; - &apos;日&apos;)
dddd	曜日（長い） (&apos;月曜日&apos; - &apos;日曜日&apos;)
M	月（ゼロなし） (1 - 12)
MM	月（ゼロ埋め） (01 - 12)
MMM	月の名称（短い） (&apos;1月&apos; - &apos;12月&apos;)
MMMM	月の名称 (長い） (&apos;1月&apos; - &apos;12月&apos;、※日本語では上記と同じ)
yy	西暦年(2桁) (00 - 99)
yyyy	西暦年(4桁)

そのほかの文字は解釈されず、テキストとして表示されます。
上記の解釈される文字も、シングルクオーテーション(&apos;)で括ると
一般の文字として扱われ、上記の解釈はされません。


日付形式の指定:</translation>
    </message>
</context>
</TS>

==> lxqt-l10n-0.12.0-1-src.tar.xz: lxqt-l10n-0.12.0/lxqt-panel/plugin-clock/clock_ja.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ja">
<context>
    <name>FirstDayCombo</name>
    <message>
        <location filename="../../../lxqtclockconfiguration.cpp" line="49"/>
        <source>&lt;locale based&gt;</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>LXQtClock</name>
    <message>
        <location filename="../../../lxqtclock.cpp" line="57"/>
        <source>Date&amp;Time (clock) plugin is deprecated</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../lxqtclock.cpp" line="58"/>
        <source>The &lt;strong&gt;clock&lt;/strong&gt; plugin is deprecated and will be removed in future version of LXQt. Consider replacing it with &lt;strong&gt;worldclock&lt;/strong&gt;.&lt;br/&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../lxqtclock.cpp" line="60"/>
        <source>don&apos;t show this again</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>LXQtClockConfiguration</name>
    <message>
        <location filename="../../../lxqtclockconfiguration.ui" line="14"/>
        <source>Clock Settings</source>
        <translation>時計の設定</translation>
    </message>
    <message>
        <location filename="../../../lxqtclockconfiguration.ui" line="20"/>
        <source>Time</source>
        <translation>時刻</translation>
    </message>
    <message>
        <location filename="../../../lxqtclockconfiguration.ui" line="26"/>
        <source>&amp;Show seconds</source>
        <translation>秒を表示(&amp;S)</translation>
    </message>
    <message>
        <location filename="../../../lxqtclockconfiguration.ui" line="33"/>
        <source>12 &amp;hour style</source>
        <translation>12時間表示(&amp;H)</translation>
    </message>
    <message>
        <location filename="../../../lxqtclockconfiguration.ui" line="40"/>
        <source>&amp;Use UTC</source>
        <translation>UTCを使用する(&amp;U)</translation>
    </message>
    <message>
        <location filename="../../../lxqtclockconfiguration.ui" line="59"/>
        <source>Date &amp;format</source>
        <translation>日時の形式(&amp;F)</translation>
    </message>
    <message>
        <location filename="../../../lxqtclockconfiguration.ui" line="76"/>
        <source>&amp;Do not show date</source>
        <translation>日付を表示しない(&amp;D)</translation>
    </message>
    <message>
        <location filename="../../../lxqtclockconfiguration.ui" line="86"/>
        <source>Show date &amp;before time</source>
        <translation>日付のあとに時刻(&amp;B)</translation>
    </message>
    <message>
        <location filename="../../../lxqtclockconfiguration.ui" line="93"/>
        <source>Show date &amp;after time</source>
        <translation>時刻のあとに日付(&amp;A)</translation>
    </message>
    <message>
        <location filename="../../../lxqtclockconfiguration.ui" line="100"/>
        <source>Show date below time on new &amp;line</source>
        <translation>時刻の下に日付(&amp;L)</translation>
    </message>
    <message>
        <location filename="../../../lxqtclockconfiguration.ui" line="107"/>
        <source>First day of week in calendar</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../lxqtclockconfiguration.ui" line="124"/>
        <source>Orientation</source>
        <translation>回転</translation>
    </message>
    <message>
        <location filename="../../../lxqtclockconfiguration.ui" line="130"/>
        <source>Auto&amp;rotate when the panel is vertical</source>
        <translation>パネルが縦のときに自動回転(&amp;R)</translation>
    </message>
    <message>
        <location filename="../../../lxqtclockconfiguration.ui" line="50"/>
        <source>Date</source>
        <translation>日付</translation>
    </message>
    <message>
        <location filename="../../../lxqtclockconfiguration.cpp" line="268"/>
        <source>Input custom date format</source>
        <translation>日付の表示形式を指定</translation>
    </message>
    <message>
        <location filename="../../../lxqtclockconfiguration.cpp" line="268"/>
        <source>Interpreted sequences of date format are:

d	the day as number without a leading zero (1 to 31)
dd	the day as number with a leading zero (01 to 31)
ddd	the abbreviated localized day name (e.g. &apos;Mon&apos; to &apos;Sun&apos;).
dddd	the long localized day name (e.g. &apos;Monday&apos; to &apos;Sunday&apos;).
M	the month as number without a leading zero (1-12)
MM	the month as number with a leading zero (01-12)
MMM	the abbreviated localized month name (e.g. &apos;Jan&apos; to &apos;Dec&apos;).
MMMM	the long localized month name (e.g. &apos;January&apos; to &apos;December&apos;).
yy	the year as two digit number (00-99)
yyyy	the year as four digit number

All other input characters will be treated as text.
Any sequence of characters that are enclosed in single quotes (&apos;)
will also be treated as text and not be used as an expression.


Custom date format:</source>
        <translation>解釈される記法:

d	日(ゼロなし) (1 - 31)
dd	日(ゼロ埋め) (01 - 31)
ddd	 曜日（短い） (&apos;月&apos; - &apos;日&apos;)
dddd	曜日（長い） (&apos;月曜日&apos; - &apos;日曜日&apos;)
M	月（ゼロなし） (1 - 12)
MM	月（ゼロ埋め） (01 - 12)
MMM	月の名称（短い） (&apos;1月&apos; - &apos;12月&apos;)
MMMM	月の名称 (長い） (&apos;1月&apos; - &apos;12月&apos;、※日本語では上記と同じ)
yy	西暦年(2桁) (00 - 99)
yyyy	西暦年(4桁)

そのほかの文字は解釈されず、テキストとして表示されます。
上記の解釈される文字も、シングルクオーテーション(&apos;)で括ると
一般の文字として扱われ、上記の解釈はされません。


日付形式の指定:</translation>
    </message>
</context>
</TS>
